@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1603';
+our $VERSION = '0.1604';
 
 use Math::Bezier;
 use MIDI::Simple;
@@ -111,15 +111,15 @@ has triplet_sixteenth             => (is => 'ro', default => sub { 'tsn' });
 has dotted_sixteenth              => (is => 'ro', default => sub { 'dsn' });
 has double_dotted_sixteenth       => (is => 'ro', default => sub { 'ddsn' });
 has thirtysecond                  => (is => 'ro', default => sub { 'yn' });
-has triplet_thirtysecond          => (is => 'ro', default => sub { 'dyn' });
+has triplet_thirtysecond          => (is => 'ro', default => sub { 'tyn' });
 has dotted_thirtysecond           => (is => 'ro', default => sub { 'dyn' });
 has double_dotted_thirtysecond    => (is => 'ro', default => sub { 'ddyn' });
 has sixtyfourth                   => (is => 'ro', default => sub { 'xn' });
-has triplet_sixtyfourth           => (is => 'ro', default => sub { 'dxn' });
+has triplet_sixtyfourth           => (is => 'ro', default => sub { 'txn' });
 has dotted_sixtyfourth            => (is => 'ro', default => sub { 'dxn' });
 has double_dotted_sixtyfourth     => (is => 'ro', default => sub { 'ddxn' });
 has onetwentyeighth               => (is => 'ro', default => sub { 'on' });
-has triplet_onetwentyeighth       => (is => 'ro', default => sub { 'don' });
+has triplet_onetwentyeighth       => (is => 'ro', default => sub { 'ton' });
 has dotted_onetwentyeighth        => (is => 'ro', default => sub { 'don' });
 has double_dotted_onetwentyeighth => (is => 'ro', default => sub { 'ddon' });
 
@@ -372,7 +372,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1603
+version 0.1604
 
 =head1 SYNOPSIS
 
